# this file must be UTF-8 encoded
#####################################################################
#
# Nepali Language text and icon macros 
#
######################################################################
#
# This is the main macro file for translation when creating an 
# interface in another language.

# Under the 'text macros' comments are text macros of the form:
# _macroname_ {macro value}
# Everything between the {} is the text to be translated. This text 
# may itself contain macros (i.e. characters other than space between
# underscore characters, e.g. _about:numdocs_ or _textpage_). These
# macro names occurring within text shouldn't be translated but should
# be left as they are. Underscores or curly brackets occurring 
# naturally within the text should be escaped with a leading backslash
# (i.e. '\_', '\{' or '\}).
#
# Comment lines (other than those described above) need not be 
# translated (i.e. any lines beginning with '#', like this line).
#
# The simplest way to translate this file is to save it as something
# else (e.g. french.dm) and work through translating all the text
# macro values and icon comments.
#
######################################################################


######################################################################
# Global (base) package
package Global
######################################################################


#------------------------------------------------------------
# text macros
#------------------------------------------------------------

_textperiodicals_ [l=ne] {आवधिक}

# these three used by the default format statement of the demo and dls collections.
# -- Missing translation: _textsource_ 
_textdate_ [l=ne] {प्रकाशित मिति }
_textnumpages_ [l=ne]  {पृष्ठ संख्या }

_textsignin_ [l=ne] {भित्र पस्नुहोस}

# -- Missing translation: _textdefaultcontent_ 

_textdefaulttitle_ [l=ne] {जि‌ एस डि एल को दोष}

# -- Missing translation: _textbadcollection_ 

# -- Missing translation: _textselectpage_

# -- Missing translation: _collectionextra_ 

# this is only used by the collector (where the above _collectionextra_
# macro will always be set to another value)
# -- Missing translation: _collectorextra_

_textdescrcollection_ [l=ne] {}
_textdescrabout_ [l=ne] {पृष्ठका वारेमा}
_textdescrhome_ [l=ne] {गृह पृष्ठ}
_textdescrhelp_ [l=ne] {सहयोगी पृष्ठ}
_textdescrpref_ [l=ne] {प्राथमिकता प्राप्त पृष्ठ}
_textdescrgreenstone_ [l=ne] {ग्रीनस्टोन डिजिटल लाइव्रेरी सफ्टवेयर}
_textdescrusab_ [l=ne] {प्रयोग गर्ने कार्यमा के कुरा गाह‍ो पाउनुभयो}


# Metadata names and navigation bar labels

_textSearch_ [l=ne] {खोज}
_labelSearch_ [l=ne] {खोज}

# Dublin Core Metadata Element Set, Version 1.1
_textTitle_ [l=ne] {शीर्षक}
_labelTitle_ [l=ne] {शीर्षक A-Z}
_textCreator_ [l=ne] {सिर्जना गर्ने मान्छे}
# -- Missing translation: _labelCreator_
_textSubject_ [l=ne] {विषय}
_labelSubject_ [l=ne] {विषयहरु}
_textDescription_ [l=ne] {विवरण}
_labelDescription_ [l=ne] {विवरण}
_textPublisher_ [l=ne] {प्रकाशक}
_labelPublisher_ [l=ne] {प्रकाशक}
_textContributor_ [l=ne] {अनुदाता}
_labelContributor_ [l=ne] {सहभागीहरु}
_textDate_ [l=ne] {मिति}
_labelDate_ [l=ne] {मिति}
_textType_ [l=ne] {लेख्नुहोस}
_labelType_ [l=ne] {किसिम}
_textFormat_ [l=ne] {संरचना}
_labelFormat_ [l=ne] {संरचना}
_textIdentifier_ [l=ne] {परिचयदाता}
_labelIdentifier_ [l=ne] {परिचायक}
_textSource_ [l=ne] {फाइलको नाम}  # Not true DC, kept for legacy reasons
_labelSource_ [l=ne] {फाइलका नामहरु}  # Not true DC, kept for legacy reasons
_textLanguage_ [l=ne] {भाषा}
_labelLanguage_ [l=ne] {भाषाहरु}
_textRelation_ [l=ne] {सम्बन्ध}
_labelRelation_ [l=ne] {सम्बन्धहरु}
_textCoverage_ [l=ne] {क्षेत्र}
_labelCoverage_ [l=ne] {क्षेत्र}
_textRights_ [l=ne] {ठीक}
_labelRights_ [l=ne] {अधिकार}

# DLS metadata set
_textOrganization_ [l=ne] {संस्था}
_labelOrganization_ [l=ne] {संस्था}
_textKeyword_ [l=ne] {मूल शव्द}
_labelKeyword_ [l=ne] {मूल शव्दहरु}
_textHowto_ [l=ne] {कसरी}
_labelHowto_ [l=ne] {कसरी ?}

# Miscellaneous Greenstone metadata
_textPhrase_ [l=ne] {उखान टुक्का}
_labelPhrase_ [l=ne] {उखान टुक्का}
_textCollage_ [l=ne] {कलेज}
_labelCollage_ [l=ne] {कलेज}
_textBrowse_ [l=ne] {देखाउनोस्}
_labelBrowse_ [l=ne] {खोज}
_textTo_ [l=ne] {लाई}
_labelTo_ [l=ne] {लाई}
_textFrom_ [l=ne] {बाट}
_labelFrom_ [l=ne] {बाट}
# -- Missing translation: _textAcronym_
# -- Missing translation: _labelAcronym_

# Navigation bar tooltip - to customize this for a specific metadata, add a macro named _textdescrXXX_ where XXX is the metadata name
# -- Missing translation: _textdescrdefault_

# -- Missing translation: _textdescrSearch_
# -- Missing translation: _textdescrType_
# -- Missing translation: _textdescrIdentifier_
_textdescrSource_ [l=ne] {फाइलको मूल नाम अनुसार खोजी गर्नुहोस्}  # Not true DC, kept for legacy reasons
# -- Missing translation: _textdescrTo_
_textdescrFrom_ [l=ne] {क्षेत्रका आधारमा खोज्नुहोस्}
_textdescrCollage_ [l=ne] {कलेजको चित्रबाट देखाउनोस्}
# -- Missing translation: _textdescrAcronym_ 
_textdescrPhrase_ [l=ne] {उखान टुक्का देखाउनुहोस}
_textdescrHowto_ [l=ne] {वर्गीकरण गर्ने तरिका हेर्नुहोस}
_textdescrBrowse_ [l=ne] {दस्तावेज हेर्नुहोस्}
_texticontext_ [l=ne] {दस्तावेज हेर्नुहोस}
_texticonclosedbook_ [l=ne] {दस्तावेजलाई खोलेर हेर्नुहोस}
_texticonnext_ [l=ne] {अघिल्लो खण्डमा जानका लागि}
_texticonprev_ [l=ne] {अघिको खण्डतर्फ}

_texticonworld_ [l=ne] {वेभ दस्तावेज हेर्नुहोस्}

_texticonmidi_ [l=ne] {MIDI दस्तावेज हेर्नुहोस}
_texticonmsword_ [l=ne] {माइक्रोसफ्ट वर्ड डकुमेन्ट हेर्नुहोस्}
_texticonmp3_ [l=ne] {MP3 दस्तावेज हेर्नुहोस्}
_texticonpdf_ [l=ne] {PDF  दस्तावेज हेर्नुहोस्}
# -- Missing translation: _texticonps_ 
_texticonppt_ [l=ne] {PowerPoint  प्रस्तुति हेर्नुहोस}
_texticonrtf_ [l=ne] {RTF दस्तावेज हेर्नुहोस्}
_texticonxls_ [l=ne] {माइक्रोसफ्ट एक्सेल दस्तावेज हेर्नुहोस}

_page_ [l=ne] {पृष्ठ }
_pages_ [l=ne] {पृष्ठ}
_of_ [l=ne] { को }
_vol_ [l=ne] {खण्ड}
_num_ [l=ne] {संख्या}

_textmonth00_ [l=ne] {}
_textmonth01_ [l=ne] {जनवरी}
_textmonth02_ [l=ne] {फेब्रुवरी}
_textmonth03_ [l=ne] {मार्च}
_textmonth04_ [l=ne] {अप्रिल}
_textmonth05_ [l=ne] {मे}
_textmonth06_ [l=ne] {जुन}
_textmonth07_ [l=ne] {जुलाई}
_textmonth08_ [l=ne] {अगस्त}
_textmonth09_ [l=ne] {सेप्टेम्वर}
_textmonth10_ [l=ne] {अक्टुवर}
_textmonth11_ [l=ne] {नोभेम्वर}
_textmonth12_ [l=ne] {डिसेम्वर}

_textdocument_ [l=ne] {दस्तावेज}
_textsection_ [l=ne] {भाग}
_textparagraph_ [l=ne] {अनुच्छेद}

_magazines_ [l=ne] {पत्रिकाहरु}

# -- Missing translation: _nzdlpagefooter_

_linktextHOME_ [l=ne] {घर}
_linktextHELP_ [l=ne] {सहयोग}
_linktextPREFERENCES_ [l=ne] {प्राथमिकताहरु}


######################################################################
# 'home' page
package home
######################################################################

_textpagetitle_ [l=ne] {ग्रीनस्टन डिजिटल पुस्तकालय}

_textnocollections_ [l=ne] {कुनै पनि किसिमको आधिकारिक समूह उपलब्ध छैन।}

_textadmin_ [l=ne] {व्यवस्थापकीय पृष्ठ}
# -- Missing translation: _textabgs_
_textgsdocs_ [l=ne] {ग्रीनस्टन दस्तावेज राखनधरन}

# -- Missing translation: _textdescradmin_ 

# -- Missing translation: _textdescrgogreenstone_ 

# -- Missing translation: _textdescrgodocs_

#####################################################################
# some macros used on the home page from other packages
#####################################################################
package gli

# -- Missing translation: _textgli_ 
# -- Missing translation: _textdescrgli_ 

package collector

_textcollector_ [l=ne] {संग्रहकर्ता}
# -- Missing translation: _textdescrcollector_ 

package depositor

# -- Missing translation: _textdepositor_ 
_textdescrdepositor_  [l=ne] {भएका समूहमा दस्तावेज जोड्न सहयोग गर्छ}

package gti

# -- Missing translation: _textgti_ 
# -- Missing translation: _textdescrtranslator_ 


######################################################################
# 'about' page
package about
######################################################################


#------------------------------------------------------------
# text macros
#------------------------------------------------------------

_textabcol_ [l=ne] {यस सँग्रहका वारेमा}

_textsubcols1_ [l=ne] {<p>सम्पूर्ण सँग्रह_1_ सहायक सँग्रह जो उपलव्ध छन् ।
 <blockquote>}

_textsubcols2_ [l=ne] {</blockquote>
प्राथमिकताका साथ तपाइले तत्काल प्रयोग गरिरहेको सामग्री परीक्षण गर्न सक्नुहुन्छ}

_titleabout_ [l=ne] {वारे}


######################################################################
# document package
package document
######################################################################


#------------------------------------------------------------
# text macros
#------------------------------------------------------------

_texticonopenbookshelf_ [l=ne] {को यस भागलाई बन्द गर्नुहोस्}
_texticonclosedbookshelf_ [l=ne] {पुस्तकालयको यो खण्ड खोलेर राखिएका सामग्री हेर्नुहोस्}
_texticonopenbook_ [l=ne] {यो किताव बन्द गर्नुहोस्}
_texticonclosedfolder_ [l=ne] {यो फोल्डरलाई खोलेर हेर्नुहोस्}
_texticonclosedfolder2_ [l=ne] {सहायक खण्ड खोल्नुहोस् }
_texticonopenfolder_ [l=ne] {यस फोल्डरलाई बन्द गर्नुहोस्}
_texticonopenfolder2_ [l=ne] {सहायक खण्ड बन्द गर्नुहोस् }
_texticonsmalltext_ [l=ne] {यस भागको मूल शव्दहरुलाई हेर्नुहोस}
_texticonsmalltext2_ [l=ne] {मुख्य शव्दहरुलाई हेर्नुहोस् }
_texticonpointer_ [l=ne] {चालु खण्ड}
_texticondetach_ [l=ne] {यो पृष्ठलाई नयाँ Window मा खोल्नुहोस्}
_texticonhighlight_ [l=ne] {खोज गरिएका पदहरुलाई हाइलाइट गर्नुहोस्}
_texticonnohighlight_ [l=ne] {खोजिएका सामग्रीहरु हाइलाइट नगर्नुहोस्}
# -- Missing translation: _texticoncontracttoc_
_texticonexpandtoc_ [l=ne] {विषय सूची विस्तार}
_texticonexpandtext_ [l=ne] {सम्पूर्ण अक्षर देखाउनुहोस्}
_texticoncontracttext_ [l=ne] {छानिएका सामग्री मात्र प्रस्तुत गर्नुहोस}
_texticonwarning_ [l=ne] {<b> सतर्कता</b>}
# -- Missing translation: _texticoncont_ 

_textltwarning_ [l=ne] {<div class="buttons">_imagecont_</div>
 _iconwarning_
 }

_textgoto_ [l=ne] {पृष्ठमा जानुहोस}
# -- Missing translation: _textintro_

_textCONTINUE_ [l=ne] {निरन्तरता दिनुस्}

_textEXPANDTEXT_ [l=ne] {अक्षर बढाउनुस}

_textCONTRACTCONTENTS_ [l=ne] {सम्झौताका बुंदाहरु}

_textDETACH_ [l=ne] {छुट्याउनोस}

# -- Missing translation: _textEXPANDCONTENTS_ 

_textCONTRACT_ [l=ne] {सम्झौताका बुंदाहरु}

_textHIGHLIGHT_ [l=ne] {आकर्षण}

# -- Missing translation: _textNOHIGHLIGHT_ 

_textPRINT_ [l=ne] {प्रिन्ट}

_textnextsearchresult_ [l=ne] {अर्को खोज परिणाम}
_textprevsearchresult_[l=ne] {पहिलेको खोज परिणाम}

# macros for printing page
# -- Missing translation: _textreturnoriginal_ 
_textprintpage_ [l=ne] {यो पृष्ठ प्रिन्ट गर्नुहोस्}
_textshowcontents_ [l=ne] {विषय सूची देखाउनोस}
_texthidecontents_ [l=ne] {विषय सूची लुकाउनुहोस्}

######################################################################
# 'search' page
package query
######################################################################


#------------------------------------------------------------
# text macros
#------------------------------------------------------------

# this if statement produces the text 'results n1 - nn for query: querystring' or 
# 'No matches for query: querystring', depending on whether or not there were
# any matches
_textquerytitle_ [l=ne] {_If_(_thislast_, परिणाम_thisfirst_ - _thislast_ यस प्रश्नलाई: _cgiargq_, यो प्रश्न कसैसँग मेल खाँदैन: _cgiargq_)}
_textnoquerytitle_ [l=ne] {खोजको पृष्ठ}

# -- Missing translation: _textsome_ 
# -- Missing translation: _textall_ 
# -- Missing translation: _textboolean_ 
_textranked_ [l=ne] {स्तर निर्धारण}
_textnatural_ [l=ne] {प्राकृतिक}
# -- Missing translation: _textsortbyrank_ 
_texticonsearchhistorybar_ [l=ne] {इतिहास खोज्नुहोस्}

_textifeellucky_ [l=ne] {म आफूलाई भाग्यमानी ठान्दैछु}

#alt text for query buttons
_textusequery_ [l=ne] {यो प्रश्न प्रयोग गर्नुहोस्}
_textfreqmsg1_ [l=ne] {शव्द गणना }
_textpostprocess_ [l=ne] {_If_(_quotedquery_,<br><i>
प्रक्रियाको खोजी गर्न_quotedquery_ </i>)}
# -- Missing translation: _textinvalidquery_ 
# -- Missing translation: _textstopwordsmsg_ 
# -- Missing translation: _textlucenetoomanyclauses_ 

_textmorethan_ [l=ne] {भन्दा बढी }
_textapprox_ [l=ne] {वारे }
_textnodocs_ [l=ne] {कुनै सामग्री पनि यो प्रश्नसँग मेल खाँदैन}
_text1doc_ [l=ne] {यो प्रश्न एउटा दस्तावेजसंग भिडाइयो}
_textlotsdocs_ [l=ne] {यो प्रश्न सम्बन्धित कागजातसंग भिडाइयो}
_textmatches_ [l=ne] {भिडान}
_textbeginsearch_ [l=ne] {खोज्न शुरु गर्नुहोस}
# -- Missing translation: _textrunquery_ 
# -- Missing translation: _textclearform_ 

#these go together in form search:
#"Words  (fold, stem)  ... in field"
_textwordphrase_ [l=ne] {शव्दहरु}
_textinfield_ [l=ne] {…क्षेत्रमा}
# -- Missing translation: _textfoldstem_ 

_textadvquery_ [l=ne] {वा प्रश्न प्रयोग गर्नुहोस्}
_textallfields_ [l=ne] {सम्पूर्ण क्षेत्रहरु}
_texttextonly_ [l=ne] {सामग्री मात्र}
_textand_ [l=ne] {र}
_textor_ [l=ne] {अथवा}
# -- Missing translation: _textandnot_ 

# _indexselection_, _jselection_, _nselection_ and _gselection_ are set from 
# within the server - _indexselection_ is always set, but the others may be 
# unset

# -- Missing translation: _textsimplesearch_ 

# -- Missing translation: _textadvancedsearch_

# -- Missing translation: _textadvancedmgppsearch_ 

# -- Missing translation: _textadvancedlucenesearch_

# -- Missing translation: _textformsimplesearch_ 

# -- Missing translation: _textformadvancedsearchmgpp_ 

# -- Missing translation: _textformadvancedsearchlucene_ 

# -- Missing translation: _textnojsformwarning_ 
# -- Missing translation: _textdatesearch_ 
_textstartdate_ [l=ne] {मिति शुरु गर्नुहोस}
_textenddate_ [l=ne] {समाप्ति मिति}
# -- Missing translation: _textbc_ 
# -- Missing translation: _textad_ 
# -- Missing translation: _textexplaineras_ 

_textstemon_ [l=ne] {शव्दान्तहरुलाई नदेखेझै गर्नुहोस्}

_textsearchhistory_ [l=ne] {खोजको इतिहास}

#text macros for search history
_textnohistory_ [l=ne] {खोजको इतिहास नदेखाउनुहोस्}
_texthresult_ [l=ne] {परिणाम}
_texthresults_ [l=ne] {परिणाम}
_texthallwords_ [l=ne] {सम्पूर्ण शव्द}
_texthsomewords_ [l=ne] {केही शव्दहरु}
# -- Missing translation: _texthboolean_ 
_texthranked_ [l=ne] {स्तरीकरण}
# -- Missing translation: _texthcaseon_
# -- Missing translation: _texthcaseoff_ 
# -- Missing translation: _texthstemon_ 
# -- Missing translation: _texthstemoff_ 


######################################################################
# 'preferences' page
package preferences
######################################################################


#------------------------------------------------------------
# text macros
#------------------------------------------------------------

# -- Missing translation: _textprefschanged_ 
_textsetprefs_ [l=ne] {प्राथमिकता तोक्नुहोस्}
_textsearchprefs_ [l=ne] {खोज्ने प्राथमिकताहरु}
_textcollectionprefs_ [l=ne] {संग्रह प्राथमिकता}
_textpresentationprefs_ [l=ne] {प्रस्तुतीकरणका प्राथमिकताहरु}
_textpreferences_ [l=ne] {प्राथमिकता}
# -- Missing translation: _textcasediffs_ 
# -- Missing translation: _textignorecase_ 
# -- Missing translation: _textmatchcase_ 
_textwordends_ [l=ne] {शव्दान्त}
_textstem_ [l=ne] {शव्दहरुलाई वास्ता नगर्नुहोस्}
_textnostem_ [l=ne] {सम्पूर्ण शव्द भिडाउन जरुरी छ ।}
# -- Missing translation: _textaccentdiffs_ 
# -- Missing translation: _textignoreaccents_ 
# -- Missing translation: _textmatchaccents_ 

_textprefop_ [l=ne] {कुल _maxdocoption_परिणाममध्येबाट प्रति पृष्ठ _hitsperpageoption_ परिणाम देखाउनोस}
_textextlink_ [l=ne] {बाहिरिया वेभ पृष्ठहरु प्राप्त गर्नुहोस:}
_textintlink_ [l=ne] {मूल दस्तावेज यहांबाट साभार गरिएको छ: }
_textlanguage_ [l=ne] {इन्टरफेसको भाषा:}
_textencoding_ [l=ne] {इनकोडिङ्ग:}
_textformat_ [l=ne] {इण्टरफेसको सँरचना:}
_textall_ [l=ne] {सबै}
_textquerymode_ [l=ne] {खोजीको प्रणाली:}
_textsimplemode_ [l=ne] {साधारण खोज}
_textadvancedmode_ [l=ne] {वैज्ञानिक तरिकाको खोजले बुलियन खोज गर्न सक्छ}
# -- Missing translation: _textlinkinterm_ 
_textlinkdirect_ [l=ne] {सिधा उता जानुहोस्}
_textdigitlib_ [l=ne] {डिजिटल पुस्तकालय}
_textweb_ [l=ne] {वेब}
_textgraphical_ [l=ne] {चित्र सहित}
_texttextual_ [l=ne] {मूल पाठ}
_textcollectionoption_ [l=ne] {<p>
उपसंग्रहहरुलाई समावेश गर्नुहोस
 <br>}

_textsearchtype_ [l=ne] {प्रश्न शैली:}
# -- Missing translation: _textformsearchtype_ 

_textregularbox_ [l=ne] {एक हरफ}
_textlargebox_ [l=ne] {ठूलो}

_textrelateddocdisplay_ [l=ne] {सम्बन्धित दस्तावेज देखाउनोस्}
_textsearchhistory_ [l=ne] {खोजको इतिहास:}
_textnohistory_ [l=ne] {खोजको इतिहास नदेखाउनुहोस्}
_texthistorydisplay_ [l=ne] {खोजको _historynumrecords_ इतिहास देखाउनुहोस्}
_textnohistorydisplay_ [l=ne] {खोजको इतिहास नदेखाउनोस}


#####################################################################
# 'browse' package for the dynamic browsing interface
package browse
#####################################################################

_textalsoshowing_ [l=ne] {पनि देखाइदैछ}
_textdocsperpage_ [l=ne] {दस्तावेज प्रति पृष्ठ}

_textfilterby_ [l=ne] {भएका दस्तावेजहरु लिनुहोस्}
_textall_ [l=ne] {सम्पूर्ण}
_textany_ [l=ne] {कुनै}
_textwords_ [l=ne] {शव्दका}
_textleaveblank_ [l=ne] {चाहे जति दस्तावेज प्राप्त गर्न यो कोठा खाली राख्नुहोला}	    

_docs_ [l=ne] {दस्तावेज}
######################################################################
# 'help' page -- this is lower priority for translating than the
# rest of this file
package help
######################################################################


#------------------------------------------------------------
# text macros
#------------------------------------------------------------

_textHelp_ [l=ne] {सहयोग}

# Macros giving a brief help message for navigation bar access buttons
# The arguments to this will be _textXXX_ and _labelXXX_, where XXX is the metadata name. For example, to print out the help message for a titles classifier, the library will use _textdefaulthelp_(_textTitle_,_labelTitle_)
# To customize this for a specific metadata, add a macro named _textXXXhelp_ where XXX is the metadata name
# -- Missing translation: _textdefaulthelp_

# -- Missing translation: _textSearchhelp_ 
# -- Missing translation: _textTohelp_ 
# -- Missing translation: _textFromhelp_ 
# -- Missing translation: _textBrowsehelp_ 
# -- Missing translation: _textAcronymhelp_ 
# -- Missing translation: _textPhrasehelp_ 

_texthelptopicstitle_ [l=ne] {शीर्षक}

_textreadingdocs_ [l=ne] {दस्तावेज कसरी पढ्ने }

_texthelpreadingdocs_ [l=ne] {
<p> तपाई पृष्ठका बायाँतर्फ शीर्षक लेखकको नाम भेट्नु हुन्छ । त्यसपछि अगाडि जाने पृष्ठ अगाडि र पछाडि लैजाने तीर भेट्नु हुन्छ ।
 
 
<p> तल चालु दस्तावेजको मूल भेट्न सकिन्छ । जसको अन्तमा अगाडि र पछाडि लैजाने तीर भेटिन्छ । 
 
<p>शीर्षक र लेखकको नामभन्दा तल तीनवटा बटन भेटिन्छ ।
 चालु दस्तावेजको मूल पाठ खो‌ल्न <i>खोल्नका लागि</i>, 
 क्लिक क्लिक गर्नुहोस् । नयाँ Window खोल्न
 <i>छुट्टै</i>,
 मा क्लिक क्लिक गर्नुहोस् । दुईवटा दस्तावेजबीच तुलना गर्न परेमा नयाँ  Window उपयोगी हुन्छ ._ अन्तमा खोजी गरेको शव्द देखा पर्दछ ।
नदेखिने बनाउन परेमा <i>अदृश्य /i>, 

 बटनलाई क्लिक क्लिक गर्नुहोस् । 
}

# help about the icons
_texthelpopenbookshelf_ [l=ne] {किताबको यो खण्ड खोल्नुहोस् }
_texthelpopenbook_ [l=ne] {यो किताब खोल्नुहोस् बन्द गर्नुहोस्}
_texthelpviewtextsection_ [l=ne] {सामग्रीको यो भाग देखाउ}
_texthelpexpandtext_ [l=ne] {सम्पूर्ण सामग्रीलाई प्रदर्शन गर्नुस नगर्नुस}
_texthelpexpandcontents_ [l=ne] {तालिकालाई विस्तार गर्ने वा नगर्ने}
_texthelpdetachpage_ [l=ne] {यस पृष्ठलाई नयाँ Window मा खोल्नुहोस्}
_texthelphighlight_ [l=ne] {खोजिएका शव्दहरुलाई प्रकाशित गर्ने नगर्ने}
_texthelpsectionarrows_ [l=ne] {अघिल्लो पछिल्लो भागमा जानुहोस्}


_texthelpsearchingtitle_ [l=ne] {खास पदको खोजी कसरी गर्ने }

_texthelpsearching_ [l=ne] {
<p>
   खोज पृष्ठद्वारा यी सामान्य कार्यबाट आफ्नो खोजी पूरा गर्न सक्नुहुन्छ ।
 :<p>

   
   <ol><li>तपाईको खोजीको सामग्री के हो निर्धारण गर्नुहोस् ।
       
            <li>तपाई सम्पूर्ण सामग्री खोजी गर्न चाहनुहुन्छ वा केही अँश मात्र सो निर्धारण गर्नुहोस् ।
       
            <li>खोजी गर्नु पर्ने पद वा शव्द टाइप गर्नुहोस् ।
       
            <li><i>खोज्न शुरु गर्नुहोस् .</i> क्लिक गर्नुहोस्। .
   
      </ol>
 
 
      
<p> तपाईले खोजी शुरु गरेपछि खोजी गरेको चिजसँग मिल्दाजुल्दा बीसवटा दस्तावेज देख्न सक्नुहुन्छ । 
अन्तमा अरु बीसवटा दस्तावेजमा पुग्ने बटन भेटिन्छ > जहाँबाट अगाडि पट्टिका बीसवटा दस्तावेजमा जाने र पछाडिका बीसवटा दस्तावेजमा फर्कने बटन भेटिन्छ ।  
तपाई शीर्षक भन्ने वा शीर्षकको छेवैको बटन प्रयोग गरेर ती दस्तावेज हेर्न सकिन्छ ।
 
 
<p> तपाई आफ्नो आवश्यकता अनुसार प्राथमिकता परिवर्तन गर्न सकिन्छ । <p> 
 
}

_texthelpquerytermstitle_ [l=ne] {खोजी पद}
_texthelpqueryterms_ [l=ne] {
<p>तपाइले खोजी बक्समा टाइप गरेको शव्दलाई खोजीकर्ता शव्द भनेर व्याख्या गरिनेछ . 
प्रत्येक पद वर्णमालाका चिन्ह र अङ्कबाट बन्दछन् . दुई अलग अलग पदलाई बीचमा खाली ठाउँ राखेर पनि छुट्याउन सकिन्छ । 
 विराम चिन्हलाई प्रयोगमा ल्याइदैन . जसले गर्दा विराम चिन्ह प्रयोग गरेर खोजी गर्न सकिदैन 


 <p>उदाहरणM निम्नलिखित खोज<p>
     
<ul><kbd> अव्दुल कलाम एक सन्त वैज्ञानिक-
 
 (2002)</kbd></ul>
       
<p>को व्याख्या<p>
       
<ul><kbd>अव्दुल कलाम एक सन्त वैज्ञनिक  2002 </kbd></ul><p>
 <p>हुन्छ ।
 
}

# -- Missing translation: _texthelpmgppsearching_ 

# -- Missing translation: _texthelplucenesearching_ 

_texthelpquerytypetitle_ [l=ne] {खोजका प्रकार}
# -- Missing translation: _texthelpquerytype_ 

# -- Missing translation: _texthelpadvancedsearchtitle_ 

# -- Missing translation: _texthelpadvancedsearch_ 

# -- Missing translation: _texthelpadvsearchmg_ 

# -- Missing translation: _texthelpbooleansearch_ 

# -- Missing translation: _texthelpadvsearchmgpp_ 

# -- Missing translation: _texthelpadvancedsearchextra_

# -- Missing translation: _texthelpadvsearchlucene_ 

_texthelpformsearchtitle_ [l=ne] {क्षेत्र अनुसारको खोज}

# -- Missing translation: _texthelpformsearch_ 

# -- Missing translation: _texthelpformstemming_ 

_textdatesearch_ [l=ne] {मितिसंगै खोज्ने}

# -- Missing translation: _texthelpdatesearch_ 

_texthelpdatehowtotitle_ [l=ne] {यो सामग्री कसरी प्रयोग गर्ने :}
# -- Missing translation: _texthelpdatehowto_ 

# -- Missing translation: _texthelpdateresultstitle_ 
# -- Missing translation: _texthelpdateresults_ 

_textchangeprefs_ [l=ne] {प्राथमिकता परिवर्तन}

# -- Missing translation:_texthelppreferences_ 

_texthelpcollectionprefstitle_ [l=ne] {संग्रहका प्राथमिकता}
# -- Missing translation: _texthelpcollectionprefs_ 

_texthelplanguageprefstitle_ [l=ne] {भाषा प्राथमिकता}

# -- Missing translation: _texthelplanguageprefs_ 

_texthelppresentationprefstitle_ [l=ne] {प्रस्तुतिका प्राथमिकताहरु}
# -- Missing translation: _texthelppresentationprefs_ 

_texthelpsearchprefstitle_ [l=ne] {खोज प्राथमिकता}
# -- Missing translation: _texthelpsearchprefs_ 

# -- Missing translation: _textcasefoldprefs_ 
# -- Missing translation: _textstemprefs_
# -- Missing translation: _textaccentfoldprefs_ 
 
# -- Missing translation: _textstemoptionsprefs_ 

# -- Missing translation: _textsearchtypeprefsplain_ 

# -- Missing translation: _textsearchtypeprefsform_ 

# -- Missing translation: _textsearchtypeprefsboth_ 



_texttanumbrowseoptions_ [l=ne] { संग्रहबाट जानकारी प्राप्त गर्न निम्न _numbrowseoptions_ तरिका प्रयोग गर्नुहोस्:}

_textsimplehelpheading_ [l=ne] {संग्रहहरुबाट संग्रहको नाम सम्बन्धी जानकारी कसरी प्राप्त गर्न सकिन्छ}

# -- Missing translation: _texthelpscopetitle_
# -- Missing translation: _texthelpscope_
